@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2001-2011 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,6 +61,10 @@
 #include "ldaputil.h"
 #endif
 
+#ifdef G_OS_WIN32
+#undef interface
+#endif
+
 #define TAG_ADDRESS_INDEX    "addressbook"
 
 #define TAG_IF_ADDRESS_BOOK  "book_list"
@@ -1429,10 +1433,8 @@ static AddressDataSource *addrindex_parse_ldap( XMLFile *file ) {
 	ldapsvr_set_name( server, serverName );
 	ldapsvr_set_search_flag( server, bDynSearch );
 	ldapctl_set_matching_option( ctl, iMatch );
-#ifdef USE_LDAP_TLS
 	ldapctl_set_tls( ctl, bTLS );
 	ldapctl_set_ssl( ctl, bSSL );
-#endif
 	g_free( serverName );
 	ldapsvr_set_control( server, ctl );
 	ds->rawDataSource = server;
@@ -2033,28 +2035,6 @@ static void addrindex_consume_tree( XMLFile *file ) {
 	}
 }
 
-/*
-* Print temporary tree.
-*/
-static void addrindex_print_node( AddressCvtNode *node, FILE *stream  ) {
-	GList *list;
-
-	fprintf( stream, "Node:\ttype :%d:\n", node->type );
-	fprintf( stream, "\tname :%s:\n", node->name );
-	fprintf( stream, "\taddr :%s:\n", node->address );
-	fprintf( stream, "\trems :%s:\n", node->remarks );
-	if( node->list ) {
-		fprintf( stream, "\t--list----\n" );
-	}
-	list = node->list;
-	while( list ) {
-		AddressCvtNode *lNode = list->data;
-		list = g_list_next( list );
-		addrindex_print_node( lNode, stream );
-	}
-	fprintf( stream, "\t==list-%d==\n", node->type );
-}
-
 /*
 * Free up temporary tree.
 */
