@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -227,13 +227,19 @@ void session_destroy(Session *session)
 	g_free(session);
 }
 
-gboolean session_is_connected(Session *session)
+gboolean session_is_running(Session *session)
 {
 	return (session->state == SESSION_READY ||
 		session->state == SESSION_SEND ||
 		session->state == SESSION_RECV);
 }
 
+gboolean session_is_connected(Session *session)
+{
+	return (session->state == SESSION_SEND ||
+		session->state == SESSION_RECV);
+}
+
 void session_set_access_time(Session *session)
 {
 	session->last_access_time = time(NULL);
