@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -160,20 +160,26 @@ static gint smtp_auth(SMTPSession *session)
 
 	session->state = SMTP_AUTH;
 
-	if (session->forced_auth_type == SMTPAUTH_CRAM_MD5 ||
-	    (session->forced_auth_type == 0 &&
-	     (session->avail_auth_type & SMTPAUTH_CRAM_MD5) != 0))
+	if ((session->forced_auth_type == SMTPAUTH_CRAM_MD5
+	     || session->forced_auth_type == 0)
+            &&
+	     (session->avail_auth_type & SMTPAUTH_CRAM_MD5) != 0)
 		smtp_auth_cram_md5(session);
-	else if (session->forced_auth_type == SMTPAUTH_LOGIN ||
-		 (session->forced_auth_type == 0 &&
-		  (session->avail_auth_type & SMTPAUTH_LOGIN) != 0))
+	else if ((session->forced_auth_type == SMTPAUTH_LOGIN
+		  || session->forced_auth_type == 0)
+                 &&
+		  (session->avail_auth_type & SMTPAUTH_LOGIN) != 0)
 		smtp_auth_login(session);
-	else if (session->forced_auth_type == SMTPAUTH_PLAIN ||
-		 (session->forced_auth_type == 0 &&
-		  (session->avail_auth_type & SMTPAUTH_PLAIN) != 0))
+	else if ((session->forced_auth_type == SMTPAUTH_PLAIN
+		  || session->forced_auth_type == 0)
+                 &&
+		  (session->avail_auth_type & SMTPAUTH_PLAIN) != 0)
 		smtp_auth_plain(session);
-	else {
-		log_warning(LOG_PROTOCOL, _("SMTP AUTH not available\n"));
+	else if (session->forced_auth_type == 0) {
+		log_warning(LOG_PROTOCOL, _("No SMTP AUTH method available\n"));
+		return SM_AUTHFAIL;
+	} else {
+		log_warning(LOG_PROTOCOL, _("Selected SMTP AUTH method not available\n"));
 		return SM_AUTHFAIL;
 	}
 
