@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,6 +72,7 @@ gint export_mbox(FolderItem *default_src)
 		gtk_widget_show(window);
 	}
 
+	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	change_dir(claws_get_startup_dir());
 
 	if (default_src && default_src->path) {
@@ -92,6 +93,7 @@ gint export_mbox(FolderItem *default_src)
 	gtk_main();
 
 	gtk_widget_hide(window);
+	gtk_window_set_modal(GTK_WINDOW(window), FALSE);
 
 	return export_ok;
 }
@@ -110,7 +112,6 @@ static void export_create(void)
 	gtk_window_set_title(GTK_WINDOW(window), _("Export to mbox file"));
 	gtk_container_set_border_width(GTK_CONTAINER(window), 5);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(window), TRUE);
 	g_signal_connect(G_OBJECT(window), "delete_event",
 			 G_CALLBACK(delete_event), NULL);
@@ -218,6 +219,7 @@ static void export_ok_cb(GtkWidget *widget, gpointer data)
 	if (!src) {
 		alertpanel_error(_("Couldn't find the source folder."));
 		gtk_widget_grab_focus(src_entry);
+		g_free(mbox);
 		return;
 	} else {
 		export_ok = export_to_mbox(src, mbox);
