@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -146,7 +146,10 @@ void folder_item_prefs_save_config(FolderItem * item)
 	tmp_prefs = * item->prefs;
 
 	id = folder_item_get_identifier(item);
-	debug_print("saving prefs for %s\n", id?id:"(null)");
+	if (id == NULL)
+		return;
+
+	debug_print("saving prefs for %s\n", id);
 	prefs_write_config(param, id, FOLDERITEM_RC);
 	g_free(id);
 }
@@ -164,6 +167,12 @@ void folder_item_prefs_save_config_recursive(FolderItem * item)
 			-1, folder_item_prefs_save_config_func, NULL);
 }
 
+void folder_prefs_save_config_recursive(Folder *folder)
+{	
+	g_node_traverse(folder->node, G_PRE_ORDER, G_TRAVERSE_ALL,
+			-1, folder_item_prefs_save_config_func, NULL);
+}
+
 static FolderItemPrefs *folder_item_prefs_clear(FolderItemPrefs *prefs)
 {
 	prefs->enable_default_to = FALSE;
