@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2010 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,8 +143,8 @@ static GtkWidget *about_create_child_page_info(void)
 				NULL);
 #ifdef GENERIC_UMPC
 	gtk_text_buffer_insert(buffer, &iter, _(
-				"\n\nCopyright (C) 1999-2010\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
-				"and the Claws Mail team"), -1);
+				"\n\nCopyright (C) 1999-2011\nThe Claws Mail Team\n"
+				" and Hiroyuki Yamamoto"), -1);
 #endif
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (_("\n\nSystem Information\n")), -1,
 			"underlined-list-title", NULL);
@@ -708,8 +708,8 @@ static void about_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 0);
 #ifndef GENERIC_UMPC
 	label = gtk_label_new
-		(_("Copyright (C) 1999-2010\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
-		 "and the Claws Mail team"));
+		(_("Copyright (C) 1999-2011\nThe Claws Mail Team\n"
+		 "and Hiroyuki Yamamoto"));
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
