@@ -45,6 +45,7 @@ static char *TRANS_TEAM_LIST[] = {
 "[id] MSulchan Darmawan <bleketux@gmail.com>",
 "[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
 "[ja] kazken3 <kazken3@gmail.com>",
+"[lt] Mindaugas Baranauskas <embar@super.lt>",
 "[nl] Marcel Pol <mpol@gmx.net>",
 "[pl] Emilian Nowak <emil5@go2.pl>",
 "[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
@@ -91,6 +92,7 @@ static char *CONTRIBS_LIST[] = {
 "M. Benkmann",
 "Wilbert Berendsen",
 "Didier Barvaux",
+"Sébastien Bigaret",
 "Laurent Bigonville",
 "Jean-Luc Biord",
 "Pavlo Bohmat",
@@ -115,6 +117,7 @@ static char *CONTRIBS_LIST[] = {
 "Felix Eckhofer",
 "Charles A. Edwards",
 "Stefaan Eeckels",
+"Mikhail Efremov",
 "Willem van Engen",
 "Paul Evans",
 "Leonid Evdokimov",
@@ -167,6 +170,7 @@ static char *CONTRIBS_LIST[] = {
 "Jérôme Lelong",
 "Eric Limpens",
 "Thomas Link",
+"Reed Loden",
 "David Looney",
 "Alessandro Maestri",
 "Maki",
@@ -176,6 +180,7 @@ static char *CONTRIBS_LIST[] = {
 "HIRAMATSU Masami",
 "Yasuzaki Masayoshi",
 "Jason McCarver",
+"Yotam Medini",
 "David Mehrmann",
 "Christian Mertes",
 "Bram Metsch",
