@@ -3,7 +3,7 @@
  *
  * @Copyright (C) 2004-2006 Christian Hammond.
  * Some of this code is from gtkspell, Copyright (C) 2002 Evan Martin.
- * Adapted for Claws Mail (c) 2009 Pawel Pekala and the Claws Mail team
+ * Adapted for Claws Mail (c) 2009-2011 Pawel Pekala and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 #include "prefs_common.h"
 #include "codeconv.h"
 #include "defs.h"
+#include "gtkutils.h"
 
 static void claws_spell_entry_init		(ClawsSpellEntry *entry);
 static void claws_spell_entry_editable_init	(GtkEditableClass *iface);
@@ -427,7 +428,7 @@ void claws_spell_entry_recheck_all(ClawsSpellEntry *entry)
 	layout = gtk_entry_get_layout(GTK_ENTRY(entry));
 	pango_layout_set_attributes(layout, entry->priv->attr_list);
 
-	if (GTK_WIDGET_REALIZED(GTK_WIDGET(entry))) {
+	if (gtkut_widget_get_realized(GTK_WIDGET(entry))) {
 		rect.x = 0; rect.y = 0;
 		rect.width  = GTK_WIDGET(entry)->allocation.width;
 		rect.height = GTK_WIDGET(entry)->allocation.height;
