@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,9 @@
 #ifdef HAVE_NETWORKMANAGER_SUPPORT
 #include <NetworkManager.h>
 #endif
+#ifdef HAVE_VALGRIND
+#include <valgrind.h>
+#endif
 
 #include "claws.h"
 #include "main.h"
@@ -114,9 +117,6 @@
 #include "nntp-thread.h"
 #endif
 #include "stock_pixmap.h"
-#ifdef HAVE_VALGRIND
-#include "valgrind.h"
-#endif
 #ifdef USE_GNUTLS
 #  include "ssl.h"
 #endif
@@ -160,6 +160,10 @@ static GnomeVFSVolumeMonitor *volmon;
 static gboolean went_offline_nm;
 #endif
 
+#if !defined(NM_CHECK_VERSION)
+#define NM_CHECK_VERSION(x,y,z) 0
+#endif
+
 #ifdef HAVE_DBUS_GLIB
 static DBusGProxy *awn_proxy = NULL;
 #endif
@@ -1139,10 +1143,17 @@ int main(int argc, char *argv[])
 			"/org/freedesktop/NetworkManager",
 			"org.freedesktop.NetworkManager");
 		if (nm_proxy) {
+#if NM_CHECK_VERSION(0,8,992)
+			dbus_g_proxy_add_signal(nm_proxy, "StateChanged", G_TYPE_UINT, G_TYPE_INVALID);
+			dbus_g_proxy_connect_signal(nm_proxy, "StateChanged",
+				G_CALLBACK(networkmanager_state_change_cb),
+				NULL,NULL);
+#else
 			dbus_g_proxy_add_signal(nm_proxy, "StateChange", G_TYPE_UINT, G_TYPE_INVALID);
 			dbus_g_proxy_connect_signal(nm_proxy, "StateChange",
 				G_CALLBACK(networkmanager_state_change_cb),
 				NULL,NULL);
+#endif
 		}
 #endif
 		install_dbus_status_handler();
@@ -2738,7 +2749,14 @@ gboolean networkmanager_is_online(GError **error)
 		g_propagate_error(error, tmp_error);
 		return TRUE;
 	}
-
-	return (state == NM_STATE_CONNECTED || state == NM_STATE_UNKNOWN);
+#if NM_CHECK_VERSION(0,8,992)
+    	return (state == NM_STATE_CONNECTED_LOCAL ||
+		state == NM_STATE_CONNECTED_SITE ||
+		state == NM_STATE_CONNECTED_GLOBAL ||
+		state == NM_STATE_UNKNOWN);
+#else
+    	return (state == NM_STATE_CONNECTED ||
+		state == NM_STATE_UNKNOWN);
+#endif
 }
 #endif
