@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +64,8 @@ typedef enum
 	M_IN_MSGLIST	      = 1 << 23,
 	M_HAVE_MULTI_ACCOUNT  = 1 << 24,
 	M_FOLDER_SELECTED     = 1 << 25,
-	M_SESSION_PASSWORDS   = 1 << 26
+	M_SESSION_PASSWORDS   = 1 << 26,
+	M_DELETED_EXISTS      = 1 << 27
 } SensitiveCond;
 
 typedef enum
@@ -136,12 +137,13 @@ struct _MainWindow
 	GtkWidget	*warning_btn;
 	GtkWidget 	*tags_menu;
 	
-#ifdef HAVE_LIBSM
-	gpointer smc_conn;
-#endif
 	gboolean	 in_folder;
 	GtkActionGroup	*action_group;
 	GtkUIManager	*ui_manager;
+
+#ifdef HAVE_LIBSM
+	gpointer smc_conn;
+#endif
 };
 
 MainWindow *main_window_create		(void);
@@ -175,6 +177,9 @@ void main_window_get_position		(MainWindow	*mainwin);
 
 void main_window_progress_on		(MainWindow	*mainwin);
 void main_window_progress_off		(MainWindow	*mainwin);
+gboolean main_window_empty_trash	(MainWindow	*mainwin,
+					 gboolean	 confirm,
+					 gboolean 	 for_quit);
 
 void main_window_set_menu_sensitive	(MainWindow	*mainwin);
 
