@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -465,22 +465,22 @@ static void messageview_add_toolbar(MessageView *msgview, GtkWidget *window)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View", "Goto", "View/Goto", GTK_UI_MANAGER_MENU)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Prev", "View/Goto/Prev", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Next", "View/Goto/Next", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator1", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator1", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "PrevUnread", "View/Goto/PrevUnread", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "NextUnread", "View/Goto/NextUnread", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator2", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator2", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "PrevNew", "View/Goto/PrevNew", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "NextNew", "View/Goto/NextNew", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator3", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator3", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "PrevMarked", "View/Goto/PrevMarked", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "NextMarked", "View/Goto/NextMarked", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator4", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator4", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "PrevLabeled", "View/Goto/PrevLabeled", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "NextLabeled", "View/Goto/NextLabeled", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator5", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator5", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "LastRead", "View/Goto/LastRead", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "ParentMessage", "View/Goto/ParentMessage", GTK_UI_MANAGER_MENUITEM)
-	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator6", "View/Goto/---", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "Separator6", "View/Goto/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "NextUnreadFolder", "View/Goto/NextUnreadFolder", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI_MANAGER(msgview->ui_manager, "/Menu/View/Goto", "OtherFolder", "View/Goto/OtherFolder", GTK_UI_MANAGER_MENUITEM)
 
@@ -859,7 +859,7 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 	addrp = addr;
 	
 	/* write queue headers */
-	if (fprintf(fp, "AF:\n"
+	ok = fprintf(fp, "AF:\n"
 		    "NF:0\n"
 		    "PS:10\n"
 		    "SRH:1\n"
@@ -875,14 +875,11 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 		    "R:<%s>\n", 
 		    account->address,
 		    account->smtp_server?account->smtp_server:"",
-		    addrp) < 0) {
-		g_free(addrp);
-		fclose(fp);
-		claws_unlink(tmp);
-		return -1;
-	}
+		    addrp);
 
 	g_free(addrp);
+	if (ok < 0)
+		goto FILE_ERROR;
 	
 	/* check whether we need to save the message */
 	outbox = account_get_special_folder(account, F_OUTBOX); 
@@ -890,61 +887,40 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 		outbox = NULL;
 	if (outbox) {
 		path = folder_item_get_identifier(outbox);
-		if (fprintf(fp, "SCF:%s\n", path) < 0) {
-			g_free(path);
-			fclose(fp);
-			claws_unlink(tmp);
-			return -1;
-		}
+		ok = fprintf(fp, "SCF:%s\n", path);
 		g_free(path);
+		
+		if (ok < 0)
+			goto FILE_ERROR;
 	}		
 
-	if (fprintf(fp, "X-Claws-End-Special-Headers: 1\n") < 0) {
-		fclose(fp);
-		claws_unlink(tmp);
-		return -1;
-	}
+	if (fprintf(fp, "X-Claws-End-Special-Headers: 1\n") < 0)
+		goto FILE_ERROR;
 
 	/* Date */
 	get_rfc822_date(buf, sizeof(buf));
-	if (fprintf(fp, "Date: %s\n", buf) < 0) {
-		fclose(fp);
-		claws_unlink(tmp);
-		return -1;
-	}
+	if (fprintf(fp, "Date: %s\n", buf) < 0)
+		goto FILE_ERROR;
 
 	/* From */
 	if (account->name && *account->name) {
 		notification_convert_header
 			(buf, sizeof(buf), account->name,
 			 strlen("From: "));
-		if (fprintf(fp, "From: %s <%s>\n", buf, account->address) < 0) {
-			fclose(fp);
-			claws_unlink(tmp);
-			return -1;
-		}
+		if (fprintf(fp, "From: %s <%s>\n", buf, account->address) < 0)
+			goto FILE_ERROR;
 	} else
-		if (fprintf(fp, "From: %s\n", account->address) < 0) {
-			fclose(fp);
-			claws_unlink(tmp);
-			return -1;
-		}
+		if (fprintf(fp, "From: %s\n", account->address) < 0)
+			goto FILE_ERROR;
 
-
-	if (fprintf(fp, "To: %s\n", to) < 0) {
-		fclose(fp);
-		claws_unlink(tmp);
-		return -1;
-	}
+	if (fprintf(fp, "To: %s\n", to) < 0)
+		goto FILE_ERROR;
 
 	/* Subject */
 	notification_convert_header(buf, sizeof(buf), msginfo->subject,
 				    strlen("Subject: "));
-	if (fprintf(fp, "Subject: Disposition notification: %s\n", buf) < 0) {
-		fclose(fp);
-		claws_unlink(tmp);
-		return -1;
-	}
+	if (fprintf(fp, "Subject: Disposition notification: %s\n", buf) < 0)
+		goto FILE_ERROR;
 
 	/* Message ID */
 	if (account->set_domain && account->domain) {
@@ -965,11 +941,8 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 		}
 		generate_msgid(buf, sizeof(buf), addr);
 
-		if (fprintf(fp, "Message-ID: <%s>\n", buf) < 0) {
-			fclose(fp);
-			claws_unlink(tmp);
-			return -1;
-		}
+		if (fprintf(fp, "Message-ID: <%s>\n", buf) < 0)
+			goto FILE_ERROR;
 	}
 
 	boundary = generate_mime_boundary("DN");
@@ -984,7 +957,7 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 		qp_encode_line(enc_sub, (const guchar *)msginfo->subject);
 		g_strstrip(enc_sub);
 	}
-	if (fprintf(fp, "MIME-Version: 1.0\n"
+	ok = fprintf(fp,"MIME-Version: 1.0\n"
 			"Content-Type: multipart/report; report-type=disposition-notification;\n"
 			"  boundary=\"%s\"\n"
 			"\n"
@@ -1033,18 +1006,16 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 			orig_to?orig_to:"No To:",
 			account->address,
 			msginfo->msgid?msginfo->msgid:"NO MESSAGE ID",
-			boundary) < 0) {
-		fclose(fp);
-		claws_unlink(tmp);
-		g_free(boundary);
-		return -1;
-	}
+			boundary);
 
 	g_free(enc_sub);
 	g_free(orig_to);
 	g_free(date);
 	g_free(boundary);
 
+	if (ok < 0)
+		goto FILE_ERROR;	
+
 	if (fclose(fp) == EOF) {
 		FILE_OP_ERROR(tmp, "fclose");
 		claws_unlink(tmp);
@@ -1081,6 +1052,11 @@ static gint disposition_notification_send(MsgInfo *msginfo)
 		folder_item_remove_msg(queue, num);
 
 	return ok;
+
+FILE_ERROR:
+	fclose(fp);
+	claws_unlink(tmp);
+	return -1;
 }
 
 static gboolean find_encrypted_func(GNode *node, gpointer data)
