@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -446,6 +446,8 @@ static PrefParam param[] = {
 	 NULL, NULL, NULL},
 	{"date_format", N_("%y/%m/%d(%a) %H:%M"), &prefs_common.date_format,
 	 P_STRING, NULL, NULL, NULL},
+	{"msgview_date_format", "FALSE", &prefs_common.msgview_date_format, P_BOOL,
+	 NULL, NULL, NULL},
 
 	{"bold_unread", "TRUE", &prefs_common.bold_unread, P_BOOL,
 	 NULL, NULL, NULL},
@@ -754,6 +756,8 @@ static PrefParam param[] = {
 	 &SPECIFIC_PREFS.mime_textviewer,   P_STRING, NULL, NULL, NULL},
 	{"mime_open_command", "gedit '%s'",
 	 &SPECIFIC_PREFS.mime_open_cmd,     P_STRING, NULL, NULL, NULL},
+	{"show_inline_attachments", "TRUE", 
+	 &prefs_common.show_inline_attachments, P_BOOL, NULL, NULL, NULL},
 
 	/* Interface */
 #ifndef GENERIC_UMPC
@@ -1437,7 +1441,7 @@ void pref_set_textview_from_pref(GtkTextView *textview, const gchar *txt)
 	if (!txt) {
 		gtk_text_buffer_set_text(buffer, "", -1);
 	} else {
-		out = malloc(strlen(txt)+1);
+		out = g_malloc(strlen(txt)+1);
 
 		pref_get_unescaped_pref(out, txt);
 
@@ -1456,7 +1460,7 @@ void pref_set_entry_from_pref(GtkEntry *entry, const gchar *txt)
 	if (!txt) {
 		gtk_entry_set_text(entry, "");
 	} else {
-		out = malloc(strlen(txt)+1);
+		out = g_malloc(strlen(txt)+1);
 
 		pref_get_unescaped_pref(out, txt);
 
