@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -711,6 +711,9 @@ static void textview_add_part(TextView *textview, MimeInfo *mimeinfo)
 				else
 					pixbuf = gdk_pixbuf_new_from_file(filename, &error);
 			}
+			if (textview->stop_loading) {
+				return;
+			}
 			if (error != NULL) {
 				g_warning("%s\n", error->message);
 				g_error_free(error);
@@ -729,7 +732,10 @@ static void textview_add_part(TextView *textview, MimeInfo *mimeinfo)
 				uri->start = gtk_text_iter_get_offset(&iter);
 				
 				gtk_text_buffer_insert_pixbuf(buffer, &iter, pixbuf);
-				
+				if (textview->stop_loading) {
+					g_free(uri);
+					return;
+				}
 				uri->end = uri->start + 1;
 				uri->filename = procmime_get_part_file_name(mimeinfo);
 				textview->uri_list =
@@ -741,6 +747,9 @@ static void textview_add_part(TextView *textview, MimeInfo *mimeinfo)
 						&start_iter, &iter);
 			} else {
 				gtk_text_buffer_insert_pixbuf(buffer, &iter, pixbuf);
+				if (textview->stop_loading) {
+					return;
+				}
 				gtk_text_buffer_insert(buffer, &iter, " ", 1);
 			}
 
@@ -846,7 +855,7 @@ void textview_show_error(TextView *textview)
 		      "  This is probably due to a network error.\n"
 		      "\n"
 		      "  Use "));
-	TEXTVIEW_INSERT_LINK(_("'View Log'"), "sc://view_log", NULL);
+	TEXTVIEW_INSERT_LINK(_("'Network Log'"), "sc://view_log", NULL);
 	TEXTVIEW_INSERT(_(" in the Tools menu for more information."));
 	textview_show_icon(textview, GTK_STOCK_DIALOG_ERROR);
 }
@@ -1018,7 +1027,7 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 			argv = strsplit_with_quote(buf, " ", 0);
 			close(1);
 			close(pfd[0]);
-			dup(pfd[1]);
+			rc = dup(pfd[1]);
 			rc = execvp(argv[0], argv);
 			close(pfd[1]);
 			g_print(_("The command to view attachment "
@@ -2168,12 +2177,20 @@ static void textview_show_header(TextView *textview, GPtrArray *headers)
 		    procheader_headername_equal(header->name, "To")      ||
 		    procheader_headername_equal(header->name, "Cc"))
 			unfold_line(header->body);
-
-		if ((procheader_headername_equal(header->name, "X-Mailer") ||
-		     procheader_headername_equal(header->name,
+		
+		if (procheader_headername_equal(header->name, "Date") &&
+		    prefs_common.msgview_date_format) {
+			gchar hbody[80];
+			
+			procheader_date_parse(hbody, header->body, sizeof(hbody));
+			gtk_text_buffer_get_end_iter (buffer, &iter);
+			gtk_text_buffer_insert_with_tags_by_name
+				(buffer, &iter, hbody, -1, "header", NULL);
+		} else if ((procheader_headername_equal(header->name, "X-Mailer") ||
+				procheader_headername_equal(header->name,
 						 "X-Newsreader")) &&
-		    (strstr(header->body, "Claws Mail") != NULL ||
-		     strstr(header->body, "Sylpheed-Claws") != NULL)) {
+				(strstr(header->body, "Claws Mail") != NULL ||
+				strstr(header->body, "Sylpheed-Claws") != NULL)) {
 			gtk_text_buffer_get_end_iter (buffer, &iter);
 			gtk_text_buffer_insert_with_tags_by_name
 				(buffer, &iter, header->body, -1,
@@ -2670,7 +2687,8 @@ static gboolean textview_uri_button_pressed(GtkTextTag *tag, GObject *obj,
 			} 
 			return TRUE;
 		} else if (qlink && bevent->button == 1) {
-			textview_toggle_quote(textview, NULL, uri, FALSE);
+			if (prefs_common.hide_quoted)
+				textview_toggle_quote(textview, NULL, uri, FALSE);
 			return TRUE;
 		} else if (!g_ascii_strncasecmp(uri->uri, "mailto:", 7)) {
 			if (bevent->button == 3) {
